@@ -5,6 +5,7 @@ import os
 import ujson as json
 from aiohttp import ClientSession
 from scrapy.utils.python import to_unicode
+from scrapy.utils.url import parse_url
 
 from lich_linkextractor.utils import as_deferred
 
@@ -62,10 +63,6 @@ class AyncExtractor:
                 "Content": to_unicode(base64.encodebytes(response.body)),
                 "ContentType": to_unicode(response.headers.get("Content-Type")),
             }
-            redirect_urls=response.request.meta.get("redirect_urls", None)
-            extractor_redirect_switch=response.request.meta.get("extractor.redirect.switch", False)
-            if redirect_urls is not None and len(redirect_urls) > 0 and not extractor_redirect_switch:
-                base_ex_req["URL"] = redirect_urls[0]
         else:
             render_body = json.loads(response.body.decode("utf8"))
             if (
@@ -109,6 +106,14 @@ class AyncExtractor:
                     or isinstance(v, bool)
                 ):
                     ex_req[key_map[key]] = v
+
+            redirect_urls=response.request.meta.get("redirect_urls", None)
+            extractor_redirect_switch=response.request.meta.get("extractor.redirect.switch", False)
+            if ex_req[key_map["same_domain_only"]] and redirect_urls is not None and len(redirect_urls) > 0 and not extractor_redirect_switch:
+                root_host=parse_url(redirect_urls[0]).netloc.lower()
+                if root_host and isinstance(ex_req[key_map["allow_domains"]], list):
+                    ex_req[key_map["allow_domains"]].append(root_host)
+                    ex_req[key_map["same_domain_only"]] = False
             resp = await self._send(self.server_addr, json.dumps(ex_req), 3)
             s = set()
             for value in resp.values():
